# Codecov ditches Bash Uploader for a NodeJS executable
## Codecov has now introduced a new cross-platform uploader meant to replace its former Bash Uploader. The new uploader is available as a static binary executable currently supporting the Windows, Linux, and macOS operating systems. However, some have raised concerns with the new uploader and the many dependencies it contains.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/codecov-ditches-bash-uploader-for-a-nodejs-executable/
+ Source: Bleeping Computer
+ Author: Ax Sharma
+ Date published: 12 June 2021, 08:44
+ Date scraped: 12 December 2023, 11:46

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/04/20/codecov-bg-png.png)



Software testing and code coverage company, Codecov has now introduced a cross-platform uploader meant to replace its former Bash Uploader.


This new uploader is available as a static binary executable currently supporting the Windows, Linux, and macOS operating systems.


The announcement follows the recent Codecov supply-chain incident that lasted two months, in which attackers had altered the Codecov Bash Uploader to collect sensitive credentials from customer CI/CD environments.


New NodeJS uploader to replace Codecov Bash Uploader
----------------------------------------------------


This week, Codecov launched a beta release of its all-new uploader capable of running on the Windows, Linux, Alpine Linux, and macOS operating systems.


This uploader, written in NodeJS would replace the Bash Uploader that the company previously had in place for use by customers.


"For the last 8 months, Codecov has been developing a new uploader that does not rely on the bash script that we currently provide to our customers."


"We initiated this project because, as usage of Codecov has grown and our development velocity has increased, the Bash Uploader has become increasingly complex to properly maintain," said Codecov CTO Eli Hooten.


Hooten cited multiple reasons for taking this step, including Bash scripts being difficult to maintain, extend, distribute, and test, as complexity increases.


Further, the "curl | bash" style commands previously used by the customers to upload data to Bash Uploader drew scrutiny after the recent [supply-chain attack](https://www.bleepingcomputer.com/news/security/popular-codecov-code-coverage-tool-hacked-to-steal-dev-credentials/) in which the Bash Uploader had been compromised.   


"To combat this incident from a product perspective we initially provided better documentation on [how to verify the Codecov Bash Uploader](https://about.codecov.io/blog/validating-the-bash-script-on-ci/) until our new Uploader was complete, but our ultimate long-term goal has always been to replace the Bash Uploader altogether," continued Hooten.


Additionally, Codecov states their new uploader comes with new features, added benefits, and improved security.


The uploader is offered as a natively compiled binary produced from the [open-source NodeJS code](http://github.com/codecov/uploader) that the community, customers, and anyone can audit and contribute to.


In a [blog post](https://about.codecov.io/blog/introducing-codecovs-new-uploader/), the company also explained that a compiled binary "makes it more difficult for code to be modified by a middle man," and offers enhanced security compared to the former Bash Uploader.


Moreover, the new uploader combines separate language-specific uploaders into a single executable.


However, some observers have raised concerns with regards to the new uploader.


Software developer [Maximilian Hils](https://twitter.com/maximilianhils) highlighted that the new uploader relied on **579 dependencies**, and was 43 MB in size:



![codecov tweet](https://www.bleepstatic.com/images/news/u/1164866/2021/Jun%202021/codecov%20new%20uploader/codecov-critique-tweet.jpg)**Developer expresses concerns with the new uploader** ([Twitter](https://twitter.com/maximilianhils/status/1403322785825501185))


Hils further [expressed](https://twitter.com/maximilianhils/status/1403323595057766402) surprise at some of the statements touted by Codecov, that a compiled binary was harder to modify for a man-in-the-middle, and that the new Uploader provided "a more secure, verifiable distribution when compared to the Bash Uploader." 


Another developer [Josh Pitts](https://twitter.com/ausernamedjosh) told BleepingComputer that binary patching via Man-in-the-Middle (MitM) has been a possibility for a long time, pointing to his [earlier discovery](https://www.leviathansecurity.com/blog/the-case-of-the-modified-binaries). 


Additionally, the developer said, that the new uploader binaries were not signed by Codecov:


"For the Windows and macOS versions of Codecov binaries (where they could use code signing), they do not sign the binaries."


"They do offer public key verification of the downloads and I highly recommend checking those signatures given the importance of this software," Pitts told BleepingComputer in an email interview.


For those downloading Codecov's new uploader binaries, Pitts recommends verifying them with GPG/PGP, and then host them on an internal repository like Artifactory.


This would reduce the risk of external MitM patching.


"All your servers that use Codecov could just pull from Artifactory directly instead of doing the GPG/PGP verification on each download from the Codecov website," concluded Pitts.


How to verify the integrity of the new uploader?
------------------------------------------------


Codecov has provided simple steps that customers can use to verify the integrity of its new uploader.


Along with the uploader binary, the company provides a checksum (shashum) file which is signed by their public GPG key.


Customers can run a few commands, shown below, to ensure the hash or checksum of the downloaded Uploader matches the hash provided in the checksum file, and that the checksum file is authentic (signed by Codecov's GPG key).



![codecov new uploader](https://www.bleepstatic.com/images/news/u/1164866/2021/Jun%202021/codecov%20new%20uploader/codecov-verify.jpg)**Commands to verify the integrity of the new Codecov uploader**


Codecov's PGP public key has the following fingerprint and can be downloaded from [Keybase](https://keybase.io/codecovsecurity) or other keyservers:


**Key ID:** ED779869  
**Key Fingerprint:** 2703 4E7F DB85 0E0B BC2C 62FF 806B B28A ED77 9869
The new uploader, along with the corresponding SHA256SUM, and SHA256SUM.sig files can be downloaded from [Codecov's server](http://uploader.codecov.io/).


Codecov breach reportedly impacted hundreds of networks
-------------------------------------------------------


Ever since the Codecov incident was disclosed on April 15th, U.S. federal investigators were quick to step in and [claimed](https://www.bleepingcomputer.com/news/security/hundreds-of-networks-reportedly-hacked-in-codecov-supply-chain-attack/) that Codecov attackers managed to breach hundreds of customer networks.


Over the next few weeks, as reported by BleepingComputer, multiple companies came forward disclosing impact from this two-month-long supply-chain attack:



![Codecov timeline](https://www.bleepstatic.com/images/news/u/1164866/2021/May%202021/mercari%20codecov/timeline.png)**Codecov supply-chain attack timeline updated 21-May-2021**(BleepingComputer)


The impacted companies include software manufacturer [HashiCorp](https://www.bleepingcomputer.com/news/security/hashicorp-is-the-latest-victim-of-codecov-supply-chain-attack/), cloud communications platform [Twilio](https://www.bleepingcomputer.com/news/security/twilio-discloses-impact-from-codecov-supply-chain-attack/), cloud services provider [Confluent](https://www.confluent.co.uk/blog/confluent-update-regarding-codecov-incident/), insurance company [Coalition](https://www.coalitioninc.com/blog/incident-report-in-response-to-the-recent-codecov-breach), U.S. cybersecurity firm [Rapid7](https://www.bleepingcomputer.com/news/security/rapid7-source-code-credentials-accessed-in-codecov-supply-chain-attack/), workflow management platform [Monday.com](https://www.bleepingcomputer.com/news/security/codecov-hackers-gained-access-to-mondaycom-source-code/), and most recently, e-commerce giant [Mercari](https://www.bleepingcomputer.com/news/security/e-commerce-giant-suffers-major-data-breach-in-codecov-incident/).


Considering Codecov had over 29,000 customers with many relying on the previously compromised Bash Uploader, the full impact of the incident may continue to unfold in the coming months.


Codecov users should scan their CI/CD environments and networks for [any signs of compromise](https://www.bleepingcomputer.com/news/security/codecov-starts-notifying-customers-affected-by-supply-chain-attack/), and as a safeguard, rotate any and all secrets that may have been exposed.


The newly introduced NodeJS uploader that customers are advised to switch to is expected to address some of the concerns with Codecov's former set of uploaders.


In fact, beginning Nov 1st, 2021, the company will begin performing "random unscheduled brownouts" of its Bash Uploader, purposely making it unavailable at times, and will completely phase it out by February 2022.


*Update 09:53 AM: Added comments from software developer Josh Pitts.*





## Tags:


### Autogenerated tags:
[[uploader]] [[codecov]] [[pitts]] [[supply-chain]] [[nodejs]] [[bleepingcomputer]] [[windows]] [[linux]] [[macos]] [[hooten]]
