# Dotless domains: Home to the Internet’s shortest URLs
## You may be familiar with some of the shortest internet domains used by major companies, such as m.me and fb.me from Facebook (Meta) and Twitter's t.co URL shortener. But, it's possible for live domain names to be even shorter than these choices—and contain no dots.
## Information:

+ Link: https://www.bleepingcomputer.com/news/technology/dotless-domains-home-to-the-internet-s-shortest-urls/
+ Source: Bleeping Computer
+ Author: Ax Sharma
+ Date published: 12 September 2022, 16:25
+ Date scraped: 12 September 2022, 17:01

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/12/29/Internet_domain.jpg)



You may be familiar with some of the shortest internet domains used by major companies, such as *m.me* and *fb.me* from Facebook (Meta) and Twitter's *t.co* URL shortener.


But, it's possible for live domain names to be even shorter than these choices—and contain no dots.


## *Dotless domains,* you say?


London-based software engineer [James Williams](https://github.com/jamespwilliams) has steered everyone's attention towards domains that are even shorter than the widely known *g.co* or *m.me*.


Although the vast majority of internet domains contain TLDs separated by one or more dots, turns out it's not a must for a domain.


In theory, for example, it would be possible for internet regulatory authorities to enable top-level domains (TLDs) like *com* to be a valid domain by itself and have valid DNS records resolving to a server. Had that been the case, navigating to *http://com/*would present the user with a web page.


"There's nothing stopping TLD registry operators [from] serving *A records* at the apexes of their TLD zones," explains Williams in a succinct [blog post](https://jameswillia.ms/posts/shortest-urls.html) from last month.


"For example, if Verisign (the operator of the *com* TLD registry) wished, they could add an *A record* at the apex of the *com* TLD zone – *com* would then resolve to that IP, and your browser would connect to that IP when you visited *https://com*."


"Does any registry operator actually do this though? Surprisingly, the answer is yes."


Williams gathered [a list of TLDs that have valid DNS A records](https://data.iana.org/TLD/tlds-alpha-by-domain.txt). Although not all TLDs may show a web page when entered in a web browser, some of them do.


In tests by BleepingComputer, visiting *http://ai/* in Google Chrome on macOS presented a valid webpage, that can otherwise also be reached at: http://offshore.ai/


As for Vince Cate, the cryptographer and software developer who owns and operates the *offshore.ai* domain, there's a little [history lesson](http://offshore.ai/vince/) on his website.


Previously an American citizen, Cate states that in 1994 he relocated to Anguilla, a British Overseas Territory that holds the rights to the *ai* TLD domain which Cate is involved in managing [[1](http://www.iana.org/domains/root/db/ai.html), [2](http://www.wwtld.org/aboutcctld/history/wwtld1999/elections/electoral-roll.html)].



![Navigating to ai TLD shows a valid web page](https://www.bleepstatic.com/images/news/u/1164866/2022/sep-2022/tld-dotless-domains/dotless-domain-ai.jpg)**Navigating to *http://ai* in a web browser shows a live webpage** (BleepingComputer)


Of course, the *ai* TLD in fact has valid [DNS A records](https://www.cloudflare.com/en-gb/learning/dns/dns-records/dns-a-record/) making the magic possible:



![ai dns response](https://www.bleepstatic.com/images/news/u/1164866/2022/sep-2022/tld-dotless-domains/ai-dns.jpg)**DNS A records for *ai* TLD**(BleepingComputer)


Likewise, the http://pn/ TLD shows the server's default webpage reading "It works!"



![pn domain in web browser](https://www.bleepstatic.com/images/news/u/1164866/2022/sep-2022/tld-dotless-domains/it-works-pn.jpg)**Navigating to http://pn on Chrome web browser** (BleepingComputer)


It must be noted, that our tests did not succeed with all ISPs, DNS providers and devices, and varied by the choice of web browser even when on the same device with DNS settings unchanged.


For example, visiting *ai/* during our tests on a macOS, using the ISP's default DNS provider successfully showed the webpage in Chrome and Firefox, but not Safari web browser. However, the *pn/* domain resolved seamlessly across all web browsers and devices.



![Safari did not load ai domain](https://www.bleepstatic.com/images/news/u/1164866/2022/sep-2022/tld-dotless-domains/safari-ai-domain.jpg)**Safari on macOS does not recognize the http://ai website** (BleepingComputer)


On Windows, our attempts to access pn/ and ai/ using a variety of web browsers (Chrome, Firefox, and Brave) did not always succeed, when tested with both ISP's DNS settings as well as DNS services from Cloudflare (1.1.1.1) and Google (8.8.8.8).


On a Samsung smartphone, using Chrome for Android and the mobile network operator's DNS settings posed no issues when visiting either domain. But, on iOS our test failed for *ai/.*


## Why can't all TLDs be like that?


In internal networks typically implemented by enterprises, it isn't unusual to have dotless domains reachable from within the company. For example, heading over to http://intranet/ or http://company/ may present valid websites—viewable by only staff and users on the corporate network.


But, when it comes to the world wide web, this practice is neither widely prevalent nor encouraged.


In 2013, the internet regulatory authority ICANN adopted a resolution [banning dotless domain names](https://www.icann.org/en/announcements/details/new-gtld-dotless-domain-names-prohibited-30-8-2013-en) and stating that their usage [could be harmful](https://www.iab.org/documents/correspondence-reports-documents/2013-2/iab-statement-dotless-domains-considered-harmful/) as such domains are usually expected to resolve in a local context (i.e. a corporate network).


"Dotless names would require the inclusion of, for example, an A, AAAA, or MX, record in the apex of a TLD zone in the DNS (i.e., the record relates to the TLD-string itself)," states ICANN's older announcement.


"Dotless domains would not be universally reachable and recommended strongly against their use. As a result, the SSAC recommended that the use of DNS resource records such as A, AAAA, and MX in the apex of a Top-Level Domain (TLD) should be contractually prohibited where appropriate, and strongly discouraged in all cases."


But that has still not stopped administrators of all TLDs, like *ai*, from breaking the norm.


A YCombinator Hacker News reader [chimed in](https://news.ycombinator.com/item?id=32804311) saying that typing *ai/security*, shorthand for *http://offshore.ai/security/,* in a web browser felt "very cyberpunk."


*It's quietly one of favorite things on the internet that I can reach a hacker webpage by typing in "ai/security". That's, like, better than "ai.security" or similar because it completely does away with normal TLD conventions ("civil disobedience"!). It also happens to flip the namespacing around in a way that's kinda more human ("security in the context of AI"), which is meta in its own way given the context is about humans vs machines.  

Very cyberpunk.  
  

(And I checked; ai.security is parked. Very amusing.)*
And, that's not it. It's possible for 'blank' domains to exist, at least in theory.


"Bonus fact: there's also nothing stopping ICANN [from] adding an *A record* to the apex of the root zone, which would theoretically make the *empty* hostname resolvable," explains Williams.


"I imagine most browsers etc. would consider a URL with an empty hostname invalid – Chrome considers both *http://* and *http://.* invalid, at least."


Check for yourself on different devices and browsers—do either [*ai/*](http://ai/) or *[pn/](http://pn/)*resolve for you?





## Tags:
***ipv4-adresses***: 8.8.8.8 1.1.1.1
***urls***: http://offshore.ai/ http://com/ http://intranet/ http://company/ http://and http://ai http://ai/ http://pn https://com http://pn/ http://offshore.ai/security/

### Autogenerated tags:
[[dns]] [[tld]] [[tlds]] [[bleepingcomputer]] [[webpage]] [[http://ai]] [[macos]] [[pn]] [[icann]]
