# Windows 11 won't work without a TPM - What you need to know
## Windows 11 requires a TPM 2.0 security processor to install or upgrade to Windows 11. Unfortunately, mistakes in support documents have causes conflicting information on what type of TPM you need and why you need it in the first place.
## Information:

+ Link: https://www.bleepingcomputer.com/news/microsoft/windows-11-wont-work-without-a-tpm-what-you-need-to-know/
+ Source: Bleeping Computer
+ Author: Lawrence Abrams
+ Date published: 25 June 2021, 09:15
+ Date scraped: 12 December 2023, 11:09

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/06/15/Win--11-flare.jpg)



Windows 11 requires a TPM 2.0 security processor to install or upgrade to Windows 11. Unfortunately, mistakes in support documents have causes conflicting information on what type of TPM you need and why you need it in the first place.


Yesterday, Microsoft announced the [system requirements to upgrade or install Windows 11](https://www.bleepingcomputer.com/news/microsoft/microsoft-publishes-the-windows-11-system-requirements/) and included a new PC Health Check tool that you can use to check if your hardware is compatible with Windows 11.


However, after many people ran the tool, they discovered it was reporting that "This PC can't run Windows 11," even on devices that run Windows 10 flawlessly as they do not have a TPM 2.0 installed.



![Missing TPM fails hardware check](https://www.bleepstatic.com/images/news/Microsoft/windows-11/t/tpm-requirement/tpm-2_0-required.jpg)**Missing TPM fails hardware check**


For those with hardware purchased over the past couple of years, the likely reason you see this message is that you do not have specific settings enabled in your BIOS, or you do not have a Trusted Platform Module (TPM) installed.


Why you need a TPM
------------------


A TPM is a dedicated processor used to perform hardware-based cryptographic operations to secure encryption keys and defend against malicious tampering of your hardware and the boot process.


An example of a TPM that you can purchase and add to an Asrock motherboard is shown below.



![Asrock TPM](https://www.bleepstatic.com/images/news/Microsoft/windows-11/t/tpm-requirement/tpm-module.jpg)**Asrock TPM**


TPM processors come in two versions - an older and less secure 1.2 version and a more secure 2.0 version, which is a requirement for Windows 11.


Since 2013, Intel and AMD added firmware TPM technology to many of their CPUs that perform the same functionality as a TPM 2.0 processor without the need of a dedicated module.


For Intel Process, this technology is called Intel Platform Trust Technology (Intel PTT), and for AMD, it is called AMD Platform Security Processor.


"Almost every CPU in the last 5-7 years has a TPM. For Intel its called the "Intel PTT" which you set to enabled. For AMD it would be "AMD PSP fTPM". TPMs have been required for OEM certification since at least 2015 and was announced in 2013," said David Weston, Director of Enterprise and OS Security at Microsoft.


With Windows 11, Microsoft has brought security to the forefront by requiring a TPM 2.0 or compatible technology (Intel PTT or AMD PSP fTPM) to be available.


When a [TPM 2.0 is installed in Windows](https://docs.microsoft.com/en-us/windows/security/information-protection/tpm/tpm-recommendations), the operating system can use more robust encryption to secure your Windows Hello PINs, encrypts passwords, and enables more advanced security features, such as [Windows Defender System Guard](https://docs.microsoft.com/en-us/windows/security/threat-protection/windows-defender-system-guard/how-hardware-based-root-of-trust-helps-protect-windows).


"The following Windows features require TPM 2.0: Measured Boot, Device Encryption, WD System Guard, Device Health Attestation, Windows Hello/Hello for Business, TPM Platform Crypto Provider Key Storage, SecureBIO, DRTM, vTPM in Hyper-V," Microsoft told BleepingComputer.


"It is also a foundational security component to Windows in addition to Virtualization Based Security and the enablement of Android Apps on Windows delivered in a secure way."


Unfortunately, this week, there was a bit of confusion as one Microsoft support document stated TPM 1.2 was the minimum requirement for Windows 11. In contrast, another [hardware requirements page](http://docs.microsoft.com/en-us/windows/compatibility/windows-11/) said it was TPM 2.0.



![Microsoft support doc that stated TPM 1.2 was compatible](https://www.bleepstatic.com/images/news/Microsoft/windows-11/t/tpm-requirement/old-docs.jpg)**Microsoft support doc that stated TPM 1.2 was compatible**


This conflicting information has since been fixed by Microsoft, who clarified to BleepingComputer that Windows 11 requires TPM 2.0.


What you should do
------------------


Most modern motherboards released over the past few years support dedicated TPM 1.2 or 2.0 processors.


While they support TPM, it is usually required that you purchase and install the appropriate dedicated TPM that is compatible with your motherboard and then enable it in the BIOS.



![TPM BIOS settings for an ASUS motherboard](https://www.bleepstatic.com/images/news/Microsoft/windows-11/t/tpm-requirement/tpm-bios.jpg)**TPM BIOS settings for an ASUS motherboard**


However, since Windows 11 considers TPM 2.0 and the Intel PTT and AMD PSP fTPM CPU features to be equivalent, most people who have purchased a CPU over the last 5-7 years do not need to buy a dedicated TPM for their motherboard.


Instead, to achieve Windows 11 hardware compatibility, you just need to enable Intel PTT or AMD PSP fTPM support in your BIOS.



![Enabling Intel Platform Trust Technology (Intel PTT)​​​​​​​](https://www.bleepstatic.com/images/news/Microsoft/windows-11/t/tpm-requirement/intel-ptt-bios.jpg)**Enabling Intel Platform Trust Technology (Intel PTT)**


Once you enable Intel PTT or AMD PSP fTPM support in the BIOS, even if you do not have a dedicated TPM 2.0 module, the PC Health Check tool will still consider your hardware compatible with Windows 11.



![Hardware compatible with Windows 11](https://www.bleepstatic.com/images/news/Microsoft/windows-11/t/tpm-requirement/meeting-windows-11-hardware-requiremens.jpg)**Hardware compatible with Windows 11**


To enable Intel PTT or AMD PSP fTPM support is different on every motherboard but is usually found in the BIOS's advanced settings under security.


Microsoft has released a list of Windows 11 compatible [Intel](https://docs.microsoft.com/en-us/windows-hardware/design/minimum/supported/windows-11-supported-intel-processors), [AMD](https://docs.microsoft.com/en-us/windows-hardware/design/minimum/supported/windows-11-supported-amd-processors), and [Qualcomm](https://docs.microsoft.com/en-us/windows-hardware/design/minimum/supported/windows-11-supported-qualcomm-processors) CPUs.


*Update 6/25/21: Added into about Intel PTT, AMD PSP, and Microsoft's changes to support documents*





## Tags:


### Autogenerated tags:
[[windows]] [[amd]] [[microsoft]] [[psp]] [[ftpm]]
