# Microsoft Exchange servers scanned for ProxyShell vulnerability, Patch Now
## Threat actors are now actively scanning for the Microsoft Exchange ProxyShell remote code execution vulnerabilities after technical details were released at the Black Hat conference.
## Information:

+ Link: https://www.bleepingcomputer.com/news/microsoft/microsoft-exchange-servers-scanned-for-proxyshell-vulnerability-patch-now/
+ Source: Bleeping Computer
+ Author: Lawrence Abrams
+ Date published: 07 August 2021, 12:53
+ Date scraped: 11 December 2023, 16:11

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/03/10/Exchange1.jpg)



Threat actors are now actively scanning for the Microsoft Exchange ProxyShell remote code execution vulnerabilities after technical details were released at the Black Hat conference.


Before we get to the active scanning of these vulnerabilities, it is important to understand how they have been disclosed.


ProxyShell is the name for three vulnerabilities that perform unauthenticated, remote code execution on Microsoft Exchange servers when chained together.


These chained vulnerabilities are exploited remotely through Microsoft Exchange's Client Access Service (CAS) running on port 443 in IIS.


The three chained vulnerabilities used in ProxyShell attacks are:


* [CVE-2021-34473](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-34473) - Pre-auth Path Confusion leads to ACL Bypass *(Patched in April by [KB5001779](https://support.microsoft.com/en-us/topic/description-of-the-security-update-for-microsoft-exchange-server-2019-2016-and-2013-april-13-2021-kb5001779-8e08f3b3-fc7b-466c-bbb7-5d5aa16ef064)**)*
* [CVE-2021-34523](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-34523) - Elevation of Privilege on Exchange PowerShell Backend *(Patched in April by [KB5001779](https://support.microsoft.com/en-us/topic/description-of-the-security-update-for-microsoft-exchange-server-2019-2016-and-2013-april-13-2021-kb5001779-8e08f3b3-fc7b-466c-bbb7-5d5aa16ef064))*
* [CVE-2021-31207](https://msrc.microsoft.com/update-guide/en-US/vulnerability/CVE-2021-31207) - Post-auth Arbitrary-File-Write leads to RCE *(Patched in May by [KB5003435](https://support.microsoft.com/en-us/topic/description-of-the-security-update-for-microsoft-exchange-server-2019-2016-and-2013-may-11-2021-kb5003435-028bd051-b2f1-4310-8f35-c41c9ce5a2f1)**)*

Strangely, while both [CVE-2021-34473](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-34473) and [CVE-2021-34523](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-34523) were first disclosed in July, they were actually quietly patched in April's Microsoft Exchange KB5001779 cumulative update.


The vulnerabilities were discovered by Devcore Principal Security Researcher [Orange Tsai](https://twitter.com/orange_8361), whose team received a $200,000 prize for their use in April's [Pwn2Own 2021 hacking contest](https://www.bleepingcomputer.com/news/security/researchers-earn-1-2-million-for-exploits-demoed-at-pwn2own-2021/).


On Thursday, Orange Tsai gave a [Black Hat talk](http://www.blackhat.com/us-21/briefings/schedule/index.html#proxylogon-is-just-the-tip-of-the-iceberg-a-new-attack-surface-on-microsoft-exchange-server-23442) about recent Microsoft Exchange vulnerabilities he discovered when targeting the Microsoft Exchange Client Access Service (CAS) attack surface.


As part of the talk, Tsai explained that one of the components of the ProxyShell attack chain targets the Microsoft Exchange Autodiscover service.


Microsoft introduced the Autodiscover service to provide an easy way for mail client software to auto-configure itself with minimal input from the user.



![Slide from Orange Tsai's talk showing the Autodiscover URL](https://www.bleepstatic.com/images/news/security/microsoft/exchange/proxyshell/tsai-slide.jpg)**Slide from Orange Tsai's talk showing the Autodiscover URL**


After watching Orange Tsai's talk, security researchers PeterJson and Jang [published an article](https://peterjson.medium.com/reproducing-the-proxyshell-pwn2own-exploit-49743a4ea9a1) providing technical information about how they could successfully reproduce the ProxyShell exploit.


Attackers scan for vulnerable Exchange servers
----------------------------------------------


This week, security researcher [Kevin Beaumont](https://twitter.com/GossiTheDog) tweeted that a threat actor was probing his Microsoft Exchange honeypot against the server's [Autodiscover service](https://docs.microsoft.com/en-us/exchange/architecture/client-access/autodiscover?view=exchserver-2019).



> 
> Interesting thing I noticed in MailPot with Exchange servers - somebody has started targeting them using autodiscover.json, a detection avoidance and relatively undocumented feature it appears. [pic.twitter.com/MOuTaoOQL2](https://t.co/MOuTaoOQL2)
> 
> 
> — Kevin Beaumont (@GossiTheDog) [August 2, 2021](https://twitter.com/GossiTheDog/status/1422178411385065476?ref_src=twsrc%5Etfw)


While these initial attempts were unsuccessful, last night, after more details about the vulnerability were released, attackers [modified their scans to use the new Autodiscover URL](https://twitter.com/GossiTheDog/status/1423764264574242816) disclosed in Tsai's slide above.



```
https://Exchange-server/autodiscover/autodiscover.json?@foo.com/mapi/nspi/?&Email=autodiscover/autodiscover.json%3F@foo.com
```

Using the new URL, it appears that the threat actors were successfully able to detect a vulnerable system as it triggers the compilation of the ASP.NET web application.


Jang told BleepingComputer that accessing the URL will cause the ASP.NET worker process (w3wp.exe exe) to compile a web application, as shown in the image below from Beaumont's honeypot.



![Files created by the scan on Microsoft Exchange honeypot](https://www.bleepstatic.com/images/news/security/microsoft/exchange/proxyshell/dropped-files.jpg)**Files created by the scan on Microsoft Exchange honeypot**  
*Source: [Twitter](https://twitter.com/GossiTheDog/status/1423764264574242816)*


Now that threat actors are actively scanning for vulnerable Microsoft Exchange servers, Beaumont advises administrators to use Azure Sentinel to check IIS logs for the "/autodiscover/autodiscover.json" or "/mapi/nspi/" strings.



```
W3CIISLog
| where csUriStem == "/autodiscover/autodiscover.json"
| where csUriQuery has "/mapi/nspi/"
```

If the results list the targeted Autodiscover URL, then threat actors scanned your server for the vulnerability.


Threat actors are [actively trying to exploit this vulnerability](https://twitter.com/GossiTheDog/status/1423991791326482443), with little success so far. However, it is only a matter of time until successful exploitation is achieved in the wild.


It is strongly advised that Microsoft Exchange admins [install the latest cumulative updates](https://docs.microsoft.com/en-us/exchange/plan-and-deploy/install-cumulative-updates?view=exchserver-2019) so they are protected from these vulnerabilities



> 
> CVE-2021–34473 is one announced last month (but patch available in April). However, about 50% of internet exposed boxes aren't patched yet.
> 
> 
> — Kevin Beaumont (@GossiTheDog) [August 7, 2021](https://twitter.com/GossiTheDog/status/1423997607211327491?ref_src=twsrc%5Etfw)


As the ProxyShell vulnerabilities patches have already been released, the attacks should not be as far-reaching as the [ProxyLogon attacks](https://www.bleepingcomputer.com/news/security/microsoft-fixes-actively-exploited-exchange-zero-day-bugs-patch-now/) we saw in March, which led to [ransomware](https://www.bleepingcomputer.com/news/security/dearcry-ransomware-attacks-microsoft-exchange-with-proxylogon-exploits/), malware, and data theft on exposed servers.


However, Tsai states that there are currently 400,000 Microsoft Exchange servers exposed on the Internet, so there are bound to be successful attacks.


BleepingComputer has contacted Microsoft about this activity but has not heard back at this time.





## Tags:
***CVE's***: CVE-2021-34523 CVE-2021-31207 CVE-2021-34473
***email-adresses***: 3f@foo.com
***urls***: https://Exchange-server/autodiscover/autodiscover.json?@foo.com/mapi/nspi/?&Email=autodiscover/autodiscover.json%3F@foo.com

### Autogenerated tags:
[[microsoft]] [[tsai]] [[proxyshell]] [[autodiscover]] [[url]] [[kb5001779]]
