# Microsoft shares mitigations for Windows PrintNightmare zero-day bug
## Microsoft has provided mitigation guidance to block attacks on systems vulnerable to exploits targeting the Windows Print Spooler zero-day vulnerability known as PrintNightmare.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/microsoft-shares-mitigations-for-windows-printnightmare-zero-day-bug/
+ Source: Bleeping Computer
+ Author: Sergiu Gatlan
+ Date published: 02 July 2021, 02:56
+ Date scraped: 12 December 2023, 10:54

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/05/17/0_Windows-headpic.jpg)



Microsoft has provided mitigation guidance to block attacks on systems vulnerable to exploits targeting the Windows Print Spooler zero-day vulnerability known as PrintNightmare.


This remote code execution (RCE) bug—now tracked as CVE-2021-34527—impacts all versions of Windows per Microsoft, with the company still investigating if the vulnerability is exploitable on all of them.


CVE-2021-34527 allows [attackers to take over affected servers](https://www.bleepingcomputer.com/news/security/public-windows-printnightmare-0-day-exploit-allows-domain-takeover/) via remote code execution with SYSTEM privileges as it enables them to install programs, view, change, or delete data, and create new accounts with full user rights.


Under active exploitation
-------------------------


The company added in a newly released [security advisory](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-34527) that PrintNightmare has already been exploited in the wild. Microsoft didn't share who is behind the detected exploitation (threat actors or security researchers).


However, in a separate threat analytics report for Microsoft 365 Defender customers seen by BleepingComputer, Microsoft says **attackers are actively exploiting the PrintNightmare zero-day.**


At the moment, there are no security updates available to address the PrintNightmare zero-day, with Microsoft investigating the issue and working on a fix.


Microsoft also removed the confusion surrounding the bug by saying that "similar but distinct from the vulnerability that is assigned CVE-2021-1675," which was [patched in June](https://www.bleepingcomputer.com/news/microsoft/microsoft-june-2021-patch-tuesday-fixes-6-exploited-zero-days-50-flaws/).



Mitigation measures available
-----------------------------


While it hasn't released security updates to address this flaw, Microsoft provides mitigation measures to block attackers from taking over vulnerable systems.


The available options include disabling the Print Spooler service to remove printing capability locally and remotely, or disabling inbound remote printing through Group Policy to remove remote attack vector by blocking inbound remote printing operations.


In the second case, Microsoft says that "the system will no longer function as a print server, but local printing to a directly attached device will still be possible."


To mitigate the vulnerability, you have to go through one of the following two procedures:


  
**Option 1 - Disable the Print Spooler service**


If disabling the Print Spooler service is appropriate for your enterprise, use the following PowerShell commands:


`Stop-Service -Name Spooler -Force`


`Set-Service -Name Spooler -StartupType Disabled`


**Option 2 - Disable inbound remote printing through Group Policy**


You can also configure the settings via Group Policy as follows: `Computer Configuration / Administrative Templates / Printers`


Disable the “Allow Print Spooler to accept client connections:” policy to block remote attacks.


CISA also advises disabling the Print Spooler service
-----------------------------------------------------


In related news, CISA has also issued a [notification on the PrintNightmare zero-day](https://www.bleepingcomputer.com/news/security/cisa-disable-windows-print-spooler-on-servers-not-used-for-printing/) encouraging admins to disable the Windows Print Spooler service on servers **not used for printing**.


Per Microsoft's previous recommendations on how to mitigate risks on [Domain controllers with Print spooler service running](https://docs.microsoft.com/en-us/defender-for-identity/cas-isp-print-spooler), the service should be disabled on all Domain Controllers and Active Directory admin systems via a Group Policy Object due to the increased exposure to attacks.


Since this service is enabled by default on most Windows clients and server platforms, the risk of future attacks actively targeting vulnerable systems is significant.


Until Microsoft releases PrintNightmare security updates, implementing the mitigations listed above is the easiest way to ensure that threat actors—and ransomware groups in particular—will not jump at the occasion to breach your network.


*Update: Added info on PrintNightmware active exploitation.*





## Tags:
***CVE's***: CVE-2021-34527 CVE-2021-1675

### Autogenerated tags:
[[microsoft]] [[printnightmare]] [[windows]] [[zero-day]]
