# New Windows 'Pingback' malware uses ICMP for covert communication
## Today, Trustwave researchers have disclosed their findings on a novel Windows malware sample that uses Internet Control Message Protocol (ICMP) for its command-and-control (C2) activities. Dubbed "Pingback," this malware targets Windows 64-bit systems, and uses DLL Hijacking to gain persistence.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/new-windows-pingback-malware-uses-icmp-for-covert-communication/
+ Source: Bleeping Computer
+ Author: Ax Sharma
+ Date published: 04 May 2021, 09:00
+ Date scraped: 12 December 2023, 13:40

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/04/16/broken-windows-header.jpg)



Today, researchers have disclosed their findings on a novel Windows malware sample that uses Internet Control Message Protocol (ICMP) for its command-and-control (C2) activities.


Dubbed "Pingback," this malware targets Microsoft Windows 64-bit systems, and uses DLL Hijacking to gain persistence.


Abuses real Windows service to load malicious DLL
-------------------------------------------------


Today, Trustwave senior architect Lloyd Macrohon and principal security researcher Rodel Mendrez, have released their findings on a novel Windows malware that exists as a 64-bit DLL.


Of note is the malware sample's choice of the communication protocol being ICMP, which is also used by the popular [*ping*](https://en.wikipedia.org/wiki/Ping_(networking_utility)) command and the Windows [*traceroute*](https://support.microsoft.com/en-us/topic/how-to-use-tracert-to-troubleshoot-tcp-ip-problems-in-windows-e643d72b-2f4f-cdd6-09a0-fd2989c7ca8e) utility.


The malicious file in question is a mere 66-KB DLL called *oci.dll,*and is typically dropped within Windows "System" folder by another malicious process or attack vector.


The researchers soon realized that this DLL was not being loaded by the familiar Windows application *[rundll32.exe](https://docs.microsoft.com/en-us/windows-server/administration/windows-commands/rundll32)*, but instead relied on DLL Hijacking. 



![malicious DLL loaded on to system](https://www.bleepstatic.com/images/news/u/1164866/2021/May%202021/icmp%20malware%20trustwave/image2.png)**Process tree of the malicious DLL being loaded by legitimate Windows processes**  

Source: Trustwave


"We knew that the file was suspicious during our initial triaging, but we could not figure how it was loaded into the system because the DLL was not loaded through traditional *rundll32.exe,*" state Macrohon and Mendrez.


[DLL Hijacking](https://www.bleepingcomputer.com/news/security/almost-300-windows-10-executables-vulnerable-to-dll-hijacking/) is a technique used by attackers on Windows systems that involves placing a malicious DLL file in one of the folders trusted by the Windows operating system, such that a legitimate system application picks up and runs the malicious DLL file.


In this manner, attackers can exploit a real, trusted Windows process to execute their arbitrary malicious code.


Last year, BleepingComputer had reported, [about 300 Windows executables](https://www.bleepingcomputer.com/news/security/almost-300-windows-10-executables-vulnerable-to-dll-hijacking/) could be abused for DLL Hijacking.


In this case, Trustwave's researchers identified it was the Microsoft Distributed Transaction Control (msdtc) service being abused to load the malicious *oci.dll.*


In fact, *msdtc.exe* is present on the [list](http://%C2%A0https://github.com/wietze/windows-dll-hijacking/blob/master/dll_hijacking_candidates.csv#L813) of over 300 Windows executables that make the perfect candidates for DLL Hijacking, as compiled by PwC researcher [Wietze Beukema](https://twitter.com/Wietze).


On launch, the Windows *msdtc* service searches for 3 DLLs to load: *oci.dll*, *SqlLib80.dll*, and *xa80.dll*.


The real *oci.dll* represents an Oracle library (Oracle Call Interface) that exists for supporting and interacting with Oracle databases. But, here's the catch:


"By default, the three Oracle DLLs do not exist in the Windows system directory."


"So, in theory, an attacker with system privileges can drop a malicious DLL and save it using one of the DLL filenames that *MTxOCI* loads," explain the researchers.


Although the researchers experimented with dropping all 3 DLL filenames on Windows, they found that only *oci.dll* could be seamlessly loaded by the *msdtc* service.


But, where does the malicious *oci.dll* come from?


While the initial entry vector is still being investigated, the researchers suspect that another malware sample, *[updata.exe](http://www.virustotal.com/gui/file/4ff77ea841544569e9da8aa3990724d1473731e684a162014ad1ad54e8c8cef2/detection)*is behind both dropping the malicious *oci.dll* in the Windows "System" folder and configuring *msdtc* to run on every startup.


As analyzed by BleepingComputer, *updata.exe* indeed executes a sequence of commands to configure *msdtc* to run persistently and further drops *oci.dll*: 


sc stop msdtc  

sc config msdtc obj= Localsystem start= auto  

sc start msdtc

![updata.exe configures msdtc](https://www.bleepstatic.com/images/news/u/1164866/2021/May%202021/icmp%20malware%20trustwave/updata-process-graph.jpg)**updata.exe configures *msdtc* to run persistently**  

Source: BleepingComputer (analyzed on ANY.RUN)


Uses ICMP tunneling for covert communication
--------------------------------------------


The *oci.dll* malware once launched by *msdtc,* uses ICMP for stealthily receiving commands from its C2 server.


Trustwave researchers who named this malware "Pingback," state that the advantage of using ICMP for communications is that Pingback remains effectively hidden from a user.


That's because ICMP has no concept of "ports" and uses neither TCP nor UDP. As such, *oci.dll* may not be picked up by diagnostic tools like *[netstat](https://en.wikipedia.org/wiki/Netstat).*


Every ICMP packet, however, does contain a "data" field with enough space to sneak in custom data within the field and to transmit it back and forth between two systems:



![icmp packet](https://www.bleepstatic.com/images/news/u/1164866/2021/May%202021/icmp%20malware%20trustwave/image8.png)**ICMP packet with "data" field being used by malware to receive bot commands**  

Source: Trustwave


"The ICMP data section is where an attacker can [piggyback](https://en.wikipedia.org/wiki/Piggybacking_(security)) an arbitrary data to be sent to a remote host. The remote host replies in the same manner, by [piggybacking] an answer into another ICMP packet and sending it back," explain Macrohon and Mendrez.


Pingback malware (*oci.dll*) simply listens for any and all inbound ICMP packets on an infected system and selectively parses packets with sequence numbers: 123**4**, 123**5**, or 123**6**.


An incoming ICMP packet with sequence number 1234 indicates to the malicious process that this request contains payload or commands, whereas 1235 and 1236 are Pingback's way of keeping track of and acknowledging if a request has been received on either end.


The data received can contain C2 commands like *shell, download, upload, exec,* etc.


In essence, these commands are used to transmit data back and forth between the attacker-controlled server and the infected system and enable a remote attacker to execute other arbitrary commands on the infected system.


BleepingComputer also noticed, *oci.dll* referenced a fictitious file path named after Visual Studio 2008 that may appear to contain legitimate project data to a casual observer, but is likely used by the Pingback malware for its nefarious activities, such as data storage:


c:\Users\XL\Documents\Visual Studio 2008\Projects\PingBackService0509\x64\Release\**PingBackService0509.pdb**
"ICMP tunneling is not new, but this particular sample piqued our interest as a real-world example of malware using this technique to evade detection," state the researchers.


But, since ICMP also has legitimate use-cases as a diagnostic tool, the researchers' advice is not to disable it, but rather putting monitoring mechanisms in place to detect any suspicious ICMP traffic.


Trustwave's detailed technical findings are provided in a [blog post](https://www.trustwave.com/en-us/resources/blogs/spiderlabs-blog/backdoor-at-the-end-of-the-icmp-tunnel/). The researchers have also created a proof-of-concept [C2 bot](https://github.com/SpiderLabs/pingback) to demonstrate some of Pingback's commands.


The Indicators of Compromise (IOCs) associated with the Pingback malware are provided below:


File: *oci.dll*  

SHA256: E50943D9F361830502DCFDB00971CBEE76877AA73665245427D817047523667F  

SHA1: 0190495D0C3BE6C0EDBAB0D4DBD5A7E122EFBB3F  

MD5: 264C2EDE235DC7232D673D4748437969  
  

Network:  

ICMP Type=8  

Sequence Number: 1234|1235|1236  

Data size: 788 bytes





## Tags:
***MD5-hash***: 264C2EDE235DC7232D673D4748437969
***SHA1-hash***: 0190495D0C3BE6C0EDBAB0D4DBD5A7E122EFBB3F
***SHA256-hash***: E50943D9F361830502DCFDB00971CBEE76877AA73665245427D817047523667F

### Autogenerated tags:
[[windows]] [[icmp]] [[dll]] [[oci.dll]] [[malware]] [[msdtc]] [[pingback]] [[trustwave]] [[c2]] [[bleepingcomputer]]
