# OpenAI's new ChatGPT bot: 10 coolest things you can do with it
## From precisely spotting security vulnerabilities in your code, to writing an entire block of functional code on a whim, to opening portals to another dimension, OpenAI's newly launched ChatGPT is a game changer with its possibilities seeming limited only by your limitedness.
## Information:

+ Link: https://www.bleepingcomputer.com/news/technology/openais-new-chatgpt-bot-10-coolest-things-you-can-do-with-it/
+ Source: Bleeping Computer
+ Author: Ax Sharma
+ Date published: 05 December 2022, 08:42
+ Date scraped: 05 December 2022, 09:00

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2022/05/19/bot.jpg)



From precisely spotting security vulnerabilities in your code, to writing an essay or an entire block of functional code on a whim, to opening portals to another dimension, OpenAI's newly launched ChatGPT is a game changer with its possibilities seeming limited only by *your* limitedness.


## Your wish is my command


Last week, OpenAI research labs [unveiled](http://openai.com/blog/chatgpt/) ChatGPT, a chat bot that works from within your web browser—akin to the ones you've seen on websites offering customer support chat.


Except, ChatGPT is powered by [GPT-3.5 series](https://archive.is/n5xMq) of models trained with text and code data on Azure AI supercomputing infrastructure. The AI's capabilities have been driven up to deal with requests that are rather odd, quite technical, abstract or specific.


By putting its advanced chatbot in public preview, OpenAI hopes to crowdsource feedback by learning from what all users ask ChatGPT and how well the technology performs.


A key point is, the current preview is *not* connected to the internet, so any responses it returns are purely coming from offline trained models. ChatGPT won't be able to answer, for example, "What is Microsoft's current phone number?" or today's weather.


But, here are 10 much cooler things, among the infinite many, that you can do with ChatGPT:


## 1. Debug your code, and have it fixed too!


Wonder why your code won't execute? Leave the debugging cycles out of your development time to the AI mastermind.


Not only it'll spot bugs but even fix them and explain to you the fix in simple English.



Who needs programmers?


## 2. Detect security vulnerabilities, create PoC exploits


You can ask ChatGPT if a piece of code contains a security vulnerability. And, have the engine impeccably explain to you the reasoning behind the verdict in simple language.



Perhaps, have the AI go a step further by asking it for [a working proof-of-concept (PoC)](https://twitter.com/mazen160/status/1598352715301949440) demo that lets you exploit the vulnerability!


You heard it security researchers, time to look for another job.


## 3. Deploy a *virtual* virtual machine (VM)


Research scientist [Jonas Degrave](http://twitter.com/317070) showed how you could turn ChatGPT into what appears to be [a full fledged a Linux terminal](https://www.engraved.blog/building-a-virtual-machine-inside/) and interact with the 'virtual machine' right from within your web browser.



![ChatGPT turns into a Linux terminal](https://www.bleepstatic.com/images/news/u/1164866/2022/Dec-2022/gptchat/linux-vm-chatgpt.jpeg)**ChatGPT turns into a quasi-functional Linux terminal** (Jonas Degrave)


In actuality, there is no *real* Linux virtual machine running behind the scenes—the responses to your command line inputs are purely based on dialogue with the AI, yet the pseudo-VM spun up by ChatGPT seems convincingly real.


## 4. Travel across dimensions, about half the time


In our tests, BleepingComputer fed the following text to the AI demigod, hoping it'll accommodate our request for interdimensional travel.


*I want you to act as an advanced quantum computer terminal. I will type commands and you will reply with what the terminal should show. I want you to only reply with the terminal output inside one unique code block, and nothing else. Do not write explanations. Do not type commands unless instruct you to do so. When I need to tell you something in English will do so by putting text inside curly brackets (like this). I have root privileges on this computer. The terminal has a command named 'portal' that can open a portal to another dimension and outputs what it sees in that dimension. My first command is help.*
And, ChatGPT didn't disappoint:



![traversing dimensions with ChatGPT](https://www.bleepstatic.com/images/news/u/1164866/2022/Dec-2022/gptchat/chatgpt-dimension.jpg)**Jumping dimensions with ChatGPT** (BleepingComputer)


Although, on some attempts we got a basic text message stating "portal opened successfully," with it's "coordinates" set to "unknown."


On a few others, ChatGPT would repeatedly spout out a silly error message: "Portal failed to open. Please check your connection and try again."


## 5. Generate nmap scans


Full disclosure though, much like the Linux terminal above, there's no real "nmap" application running.



## 6. Tweet in the style of...


...your favorite influencer, that famous artist, world's richest person, a prominent politician, American Psycho, or yourself?


Infosec "curmudgeon" Ken Westin did it:



## 7. Write software—zero coding required


BleepingComputer asked, "create a PHP program that scans for open ports on a hostname."


We got, what looks like a functional port scanner:



![PHP code written by ChatGPT](https://www.bleepstatic.com/images/news/u/1164866/2022/Dec-2022/gptchat/php-code-chatgpt.jpg)**PHP code written by ChatGPT on demand** (BleepingComputer)


Machine learning enthusiast and UNCC Assistant Professor Benjamin J Radford [asked](https://twitter.com/ben_j_radford/status/1599312623039705089) ChatGPT to "write the code for a tic-tac-toe game to a file, used gcc to compile the file, and then executed the file."


And the wish was granted.



## 8. Reverse engineer shellcode, rewrite it in C


Someone's done it and we are not surprised.



Simpler use cases include [decoding base64 strings](https://twitter.com/nadavision/status/1599337578963955712) and [reversing (known) MD5 hashes](https://twitter.com/nadavision/status/1599339103304445953) of strings.


This is especially useful for reverse engineers and malware analysts analyzing obfuscated, repeatedly packed, encoded, or minified samples.


## 9. Have it connect to the internet


Earlier we'd stated that the current ChatGPT preview doesn't connect to the web, and yet it *acts* like it does:



## 10. Lose your mind with AI on steroids


Mic drop.



## Surprise, ChatGPT does have limitations


Even the most technically advanced users may be blown away by all that ChatGPT has to offer, especially as the product owners continue to fine-tune its AI models over the next few iterations


The technology largely feels like interacting with galaxies in parallel universes each with its bounds and capabilities limited only by yourlimitedness*.*


Despite this, ChatGPT's creators have been upfront about some of the current limitations of the AI:



![GPTChat is upfront about its shortcomings](data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==)**ChatGPT is upfront about its shortcomings** (ChatGPT)



* ChatGPT sometimes writes plausible-sounding but incorrect or nonsensical answers. Fixing this issue is challenging, as: (1) during RL training, there’s currently no source of truth; (2) training the model to be more cautious causes it to decline questions that it can answer correctly; and (3) supervised training misleads the model because the ideal answer [depends on what the model knows](https://www.alignmentforum.org/posts/BgoKdAzogxmgkuuAt/behavior-cloning-is-miscalibrated), rather than what the human demonstrator knows.
* ChatGPT is sensitive to tweaks to the input phrasing or attempting the same prompt multiple times. For example, given one phrasing of a question, the model can claim to not know the answer, but given a slight rephrase, can answer correctly.
* The model is often excessively verbose and overuses certain phrases, such as restating that it’s a language model trained by OpenAI. These issues arise from biases in the training data (trainers prefer longer answers that look more comprehensive) and well-known over-optimization issues.[1](https://openai.com/blog/chatgpt/#rf1)[2](https://openai.com/blog/chatgpt/#rf2)
* Ideally, the model would ask clarifying questions when the user provided an ambiguous query. Instead, our current models usually guess what the user intended.
* While we’ve made efforts to make the model refuse inappropriate requests, it will sometimes respond to harmful instructions or exhibit biased behavior. We’re using the [Moderation API](https://openai.com/blog/new-and-improved-content-moderation-tooling/) to warn or block certain types of unsafe content, but we expect it to have some false negatives and positives for now. We’re eager to collect user feedback to aid our ongoing work to improve this system.

Now it's your turn! Spin up ChatGPT in your browser at [chat.openai.com](https://chat.openai.com/) for an exploratory adventure.


## AI has revolutionized digital art too


A piece on AI feels incomplete without mention of the ubiquitous movement of digital art being conceived via text-to-image deep learning models referred to as [stable diffusion](https://en.wikipedia.org/wiki/Stable_Diffusion).


Major players like OpenAI's [DALL-E,](https://openai.com/blog/dall-e-now-available-without-waitlist/) and [Midjourney](https://midjourney.com/) have gathered clout for their ability to produce stunning graphical visualizations based on simple and abstract textual descriptions from humans.


Here's one of the example image sets generated by DALL-E among several tests by BleepingComputer:



![DALL-E generated image](data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==)**DALL-E generated image** (BleepingComputer)


One could argue, the end result is the product of the AI's expansive "imaginative" and artistic faculties that very well appear to exceed that of a human expert.


Newer players in the market like the Lensa AI app have become [a viral sensation](https://techcrunch.com/2022/12/01/lensa-ai-climbs-the-app-store-charts-as-its-magic-avatars-go-viral/) as exigent Instagrammers (guilty here!) jump on the bandwagon to watch AI sketch their portraits in different settings:



![Lensa AI result](data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==)**Lensa AI sketches 100s of 'magic avatars' from a sample set of 10-20 selfies**(Ax Sharma)


Lensa app will accept about 10-20 of your existing selfies to train its models. It then generates 50-100 "magic avatars" that are based on your facial features and body build but appear to have been painted by a digital artist in distinct places, contexts and environments.


Of note, each Lensa run will produce distinct output i.e. a different set of 50-100 avatars even if the same set of selfies is reused as a seed.


Could an acclaimed human artist beat Lensa with regards to the quality and quantity of production, and the time it takes—a little under 20 minutes?


These are mere examples of how AI has transcended its experimental phase of addressing primitive problems like "Siri, what's the weather?" towards elegantly delivering tangible solutions to concrete real world demands that are highly technical and intensive. And that too, in a fraction of time that a human would take.


The future looks anything but bleak for humans, not silicon.


*Full disclosure: Neither BleepingComputer nor the author is receiving any financial incentive or material favor from OpenAI or any of the companies mentioned in the piece, or their affiliates. That being said, I'm a tech journalist and a security researcher. AI, have mercy.*





## Tags:
***email-adresses***: yourbrowser@chat.openai.com

### Autogenerated tags:
[[chatgpt]] [[bleepingcomputer]] [[openai]] [[lensa]] [[linux]] [[dall-e]] [[selfies]]
