# Hackers seen exploiting bugs in browsers and popular file transfer tool
## One flaw is in open source code known as "libvpx," which is involved with handling media such as images. The other issue is with software known as WS_FTP.
## Information:

+ Link: https://therecord.media/libvpx-ws-ftp-vulnerabilities-browsers-file-transfer-tool
+ Source: The Record
+ Author: Jonathan Greig
+ Date published: 03 October 2023, 00:00
+ Date scraped: 03 October 2023, 14:01

## Article:
![Main article image](https://cms.therecord.media/uploads/pietro_jeng_n6_B49l_Tx7_NM_unsplash_e69c44e193.jpg)

A vulnerability affecting a widely used tool embedded in web browsers and a separate bug in a popular file transfer tool are being exploited by hackers, according to both government officials and cybersecurity experts.


The Cybersecurity and Infrastructure Security Agency (CISA) [warned](https://www.cisa.gov/news-events/alerts/2023/10/02/cisa-adds-one-known-exploited-vulnerability-catalog) on Monday that hackers are exploiting [CVE-2023-5217](https://security-tracker.debian.org/tracker/CVE-2023-5217) — a vulnerability affecting Google’s Chrome browser, Mozilla’s Firefox and more.


Google researchers [first published](https://chromereleases.googleblog.com/2023/09/stable-channel-update-for-desktop_27.html) information about the bug last week and said it was being [exploited by unnamed commercial spyware vendors](https://twitter.com/maddiestone/status/1707163313711497266). Google said it was keeping information about the bug restricted so that users had a chance to install a fix.


Like [another issue discovered last month](https://therecord.media/libwebp-vulnerability-more-widespread-than-expected), the vulnerability affects a media processing tool embedded within browsers. Initially the flaw only appeared to affect Google products, but other browser makers identified the same problem, with Mozilla [publishing its own advisory](https://www.mozilla.org/en-US/security/advisories/mfsa2023-44/) that rated CVE-2023-5217 as critical.


Specifically, the new bug affects an open source tool known as “[libvpx](https://github.com/webmproject/libvpx/releases/tag/v1.13.1).” Besides browsers, the code can be found in many other internet-based platforms, but it is unclear whether the vulnerability affects anything beyond browsers. The similar issue discovered last month affected the “libwebp” tool.


The flaws in both tools have reignited concerns about the security of open source software, due to the ubiquity of such code across a variety of products.


The issue is so dire that the White House held a summit last month on the topic, [unveiling a roadmap](https://www.cisa.gov/resources-tools/resources/cisa-open-source-software-security-roadmap) for how the government plans to address it.


### WS\_FTP Server exploited


Cybersecurity experts also are warning this week about the exploitation of flaws in a popular file transfer tool. Progress Software — the company behind the [widely breached MOVEit file transfer tool](https://therecord.media/tag/moveit) — said last week that another one of its products, WS\_FTP Server, has [several vulnerabilities that should be patched immediately](https://therecord.media/progress-new-file-transfer-vulnerability).


Initially, experts were heartened to discover that there was no proof-of-concept exploit available and no evidence of exploitation of CVE-2023-40044 — the most critical of the vulnerabilities disclosed


But by Saturday, incident response teams at cybersecurity company Rapid7 reported the first instances of exploitation. Several other security experts have said [ransomware gangs are seizing on the vulnerability](https://ioc.exchange/@GossiTheDog@cyberplace.social/111171187197935034).


“We saw similar attacker behavior across the incidents we observed over the weekend, which may indicate that a single adversary was behind the activity,” Caitlin Condon, head of vulnerability research at Rapid7, told Recorded Future News. “We also have not seen any data exfiltration so far.”


Condon noted that there was no evidence yet that the vulnerability was a target of [the Clop ransomware gang](https://therecord.media/tag/clop), which has used bugs in several file transfer tools to steal data from dozens of governments, schools and major companies.


In a [blog post](https://www.rapid7.com/blog/post/2023/09/29/etr-critical-vulnerabilities-in-ws_ftp-server/), Condon explained that in the evening hours of September 30, Rapid7 observed exploitation in multiple customer systems. The alerts came within minutes of each other and the process was identical across all instances.


BleepingComputer [confirmed](https://www.bleepingcomputer.com/news/security/exploit-available-for-critical-ws-ftp-bug-exploited-in-attacks/) on Monday that a proof-of-concept (PoC) exploit for CVE-2023-40044 was published by security researchers [on X](https://twitter.com/MCKSysAr/status/1707855204647899194) (formerly Twitter) this weekend. A spokesperson for Progress Software took issue with the unnamed researcher who published the PoC.


“We are disappointed in how quickly third parties released a proof of concept (POC), reverse-engineered from our vulnerability disclosure and patch, released on Sept. 27. This provided threat actors a roadmap on how to exploit the vulnerabilities while many of our customers were still in the process of applying the patch,” the spokesperson told Recorded Future News.


“We are not aware of any evidence that these vulnerabilities were being exploited prior to that release. Unfortunately, by building and releasing a POC rapidly after our patch was released, a third-party has given cyber criminals a tool to attempt attacks against our customers. We are encouraging all WS\_FTP server customers to patch their environments as quickly as possible.”


They added that while the company works with “responsible third-party research experts” on cybersecurity, it hopes that the community will “discourage the irresponsible publication of POCs rapidly following the release of security patches from software vendors.”


John Hammond, principal security researcher for the Huntress security platform, said it has less than 100 endpoints under its management that make use of the WS\_FTP service but [confirmed that exploitation was occurring](https://twitter.com/_JohnHammond/status/1708910264261980634). In at least one instance, Huntress saw actors trying to use tools to maintain access to compromised systems.


There are differing views on how many vulnerable systems are out there. Assetnote, the security company that discovered and reported the issue, [said](https://www.assetnote.io/resources/research/rce-in-progress-ws-ftp-ad-hoc-via-iis-http-modules-cve-2023-40044) there “are about 2.9k hosts on the internet that are running WS\_FTP (and also have their webserver exposed, which is necessary for exploitation).”


“Most of these online assets belong to large enterprises, governments and educational institutions,” Assetnote added.


BleepingComputer backed that figure with a search on research tool Shodan, which showed [less than 2,000 devices](https://www.shodan.io/search?query=%22WS_FTP+Server%22) running WS\_FTP Server that are currently available over the Internet.


Researchers at security firm Censys said on Monday that the number may be even lower.


“We discovered that out of the 325 WS\_FTP servers with this HTTP service running, we only found that 91 hosts (28%) have disabled the Ad Hoc Transfer module,” they said.


“Compared to the total number of WS\_FTP servers running the FTP and SCP interface, which total over 4,000 hosts, the number of potentially vulnerable servers is much lower than expected, which is not the worst news.”

[Previous article](/uk-passport-database-crime-suspects-facial-recognition-cctv)[UK passport database to be used to identify suspects from CCTV footage](/uk-passport-database-crime-suspects-facial-recognition-cctv)No new articles


## Tags:
***CVE's***: CVE-2023-40044 CVE-2023-5217

### Autogenerated tags:
[[ws_ftp]] [[cybersecurity]] [[google]] [[poc]] [[rapid7]] [[condon]]
